@@ -23,7 +23,9 @@
 
 #include <libgupnp/gupnp.h>
 #include <libgupnp-av/gupnp-av.h>
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 #include <gtk/gtk.h>
 
 typedef enum
