@@ -53,8 +53,6 @@ typedef struct _AVCPMediaServerPrivate AVCPMediaServerPrivate;
 
 struct _AVCPMediaServer {
         GUPnPDeviceProxy parent;
-
-        AVCPMediaServerPrivate *priv;
 };
 
 struct _AVCPMediaServerClass {
@@ -113,6 +111,9 @@ av_cp_media_server_search_finish (AVCPMediaServer  *self,
                                   guint32          *number_returned,
                                   GError          **error);
 
+char const * const *
+av_cp_media_server_get_search_caps (AVCPMediaServer *self);
+
 G_END_DECLS
 
 #endif /* MEDIA_SERVER_H */
