@@ -20,6 +20,8 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#include <config.h>
+
 #include <libgupnp/gupnp-root-device.h>
 #include <libgupnp/gupnp-service.h>
 #include <stdio.h>
@@ -28,10 +30,6 @@
 #include <gmodule.h>
 #include <glib/gstdio.h>
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "gui.h"
 #include "upnp.h"
 #include "main.h"
@@ -197,7 +195,7 @@ on_get_status (GUPnPService       *service,
                                   get_status (),
                                   NULL);
 
-        gupnp_service_action_return (action);
+        gupnp_service_action_return_success (action);
 }
 
 G_MODULE_EXPORT
@@ -212,7 +210,7 @@ on_get_target (GUPnPService       *service,
                                   get_status (),
                                   NULL);
 
-        gupnp_service_action_return (action);
+        gupnp_service_action_return_success (action);
 }
 
 G_MODULE_EXPORT
@@ -228,7 +226,7 @@ on_set_target (GUPnPService       *service,
                                   G_TYPE_BOOLEAN,
                                   &status,
                                   NULL);
-        gupnp_service_action_return (action);
+        gupnp_service_action_return_success (action);
 
         set_status (status);
 }
@@ -267,7 +265,7 @@ on_get_load_level_status (GUPnPService       *service,
                                   get_load_level (),
                                   NULL);
 
-        gupnp_service_action_return (action);
+        gupnp_service_action_return_success (action);
 }
 
 G_MODULE_EXPORT
@@ -282,7 +280,7 @@ on_get_load_level_target (GUPnPService       *service,
                                   get_load_level (),
                                   NULL);
 
-        gupnp_service_action_return (action);
+        gupnp_service_action_return_success (action);
 }
 
 G_MODULE_EXPORT
@@ -298,7 +296,7 @@ on_set_load_level_target (GUPnPService       *service,
                                   G_TYPE_UINT,
                                   &load_level,
                                   NULL);
-        gupnp_service_action_return (action);
+        gupnp_service_action_return_success (action);
 
         if (load_level > 100)
                 load_level = 100;
@@ -412,7 +410,7 @@ static void init_uuid (void)
         xmlNode *uuid_node;
         char *udn;
 
-        uuid = gupnp_get_uuid ();
+        uuid = g_uuid_string_random ();
         const xmlDoc *xml_doc = gupnp_xml_doc_get_doc (doc);
 
         uuid_node = xml_util_get_element ((xmlNode *) xml_doc,
@@ -776,7 +774,7 @@ context_equal (GUPnPContext *context1, GUPnPContext *context2)
 gboolean
 init_upnp (gchar **interfaces, guint port, gchar *name, gboolean ipv4, gboolean ipv6)
 {
-        GUPnPWhiteList *white_list;
+        GUPnPContextFilter *context_filter;
 
         switch_proxies = NULL;
         dimming_proxies = NULL;
@@ -809,10 +807,10 @@ init_upnp (gchar **interfaces, guint port, gchar *name, gboolean ipv4, gboolean
         g_assert (context_manager != NULL);
 
         if (interfaces != NULL) {
-                white_list = gupnp_context_manager_get_white_list
-                                            (context_manager);
-                gupnp_white_list_add_entryv (white_list, interfaces);
-                gupnp_white_list_set_enabled (white_list, TRUE);
+                context_filter = gupnp_context_manager_get_context_filter (
+                        context_manager);
+                gupnp_context_filter_add_entryv (context_filter, interfaces);
+                gupnp_context_filter_set_enabled (context_filter, TRUE);
         }
 
         g_signal_connect (context_manager,
